==> haskell-incremental-parser-0.3.3-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-incremental-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: incremental-parser
version: 0.3.3
id: incremental-parser-0.3.3-8M03ZYBCH492Gi41z92zt3
key: incremental-parser-0.3.3-8M03ZYBCH492Gi41z92zt3
license: GPL-3.0-only
copyright: (c) 2011-2018 Mario Blazevic
maintainer: blamario@yahoo.com
author: Mario Blazevic
homepage: https://github.com/blamario/incremental-parser
synopsis: Generic parser library capable of providing partial results from partial input.
description:
    This package defines yet another parser combinator library. This one is implemented using the concept of Brzozowski
    derivatives, tweaked and optimized to work with any monoidal input type. Lists, ByteString, and Text are supported out
    of the box, as well as any other data type for which the monoid-subclasses package defines instances. If the parser
    result is also a monoid, its chunks can be extracted incrementally, before the complete input is parsed.
category: Parsing
abi: f097e69fdd35215d641316954734f264
exposed: True
exposed-modules:
    Control.Applicative.Monoid Text.ParserCombinators.Incremental
    Text.ParserCombinators.Incremental.LeftBiasedLocal
    Text.ParserCombinators.Incremental.Symmetric
import-dirs: /usr/lib/ghc-8.6.5/site-local/incremental-parser-0.3.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/incremental-parser-0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/incremental-parser-0.3.3
hs-libraries: HSincremental-parser-0.3.3-8M03ZYBCH492Gi41z92zt3
depends:
    base-4.12.0.0 monoid-subclasses-0.4.6.1-BNxCTZkXUft1W2BH6V3Pm2
haddock-interfaces: /usr/share/doc/haskell-incremental-parser/html/incremental-parser.haddock
haddock-html: /usr/share/doc/haskell-incremental-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-incremental-parser-0.3.3-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-incremental-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: incremental-parser
version: 0.3.3
id: incremental-parser-0.3.3-6E7jMuPCS0m2R1Hcp8VzGY
key: incremental-parser-0.3.3-6E7jMuPCS0m2R1Hcp8VzGY
license: GPL-3.0-only
copyright: (c) 2011-2018 Mario Blazevic
maintainer: blamario@yahoo.com
author: Mario Blazevic
homepage: https://github.com/blamario/incremental-parser
synopsis: Generic parser library capable of providing partial results from partial input.
description:
    This package defines yet another parser combinator library. This one is implemented using the concept of Brzozowski
    derivatives, tweaked and optimized to work with any monoidal input type. Lists, ByteString, and Text are supported out
    of the box, as well as any other data type for which the monoid-subclasses package defines instances. If the parser
    result is also a monoid, its chunks can be extracted incrementally, before the complete input is parsed.
category: Parsing
abi: e1889dbe7fa011107f4eae9c7371858b
exposed: True
exposed-modules:
    Control.Applicative.Monoid Text.ParserCombinators.Incremental
    Text.ParserCombinators.Incremental.LeftBiasedLocal
    Text.ParserCombinators.Incremental.Symmetric
import-dirs: /usr/lib/ghc-8.6.5/site-local/incremental-parser-0.3.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/incremental-parser-0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/incremental-parser-0.3.3
hs-libraries: HSincremental-parser-0.3.3-6E7jMuPCS0m2R1Hcp8VzGY
depends:
    base-4.12.0.0 monoid-subclasses-0.4.6.1-BNxCTZkXUft1W2BH6V3Pm2
haddock-interfaces: /usr/share/doc/haskell-incremental-parser/html/incremental-parser.haddock
haddock-html: /usr/share/doc/haskell-incremental-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
